body {
    background: #eeeeee;
    /*margin: 1em;*/
    text-align: center;
    font-family: system-ui, sans-serif;
    height: 100%;
}

#title {
    font-size: 4em;
}
#version{
    font-size: .5em;
}

#uptime, #aprsis {
    font-size: 1em;
}
#callsign {
    font-size: 1.4em;
    color: #00F;
    padding-top: 8px;
    margin:10px;
}

#title_rx {
    background-color: darkseagreen;
    text-align: left;
}

#title_tx {
    background-color: lightcoral;
    text-align: left;
}

.aprsd_1 {
    background-image: url(/static/images/aprs-symbols-16-0.png);
    background-repeat: no-repeat;
    background-position: -160px -48px;
    width: 16px;
    height: 16px;
}

.wc-container {
  display: flex;
  flex-flow: column;
  height: 100%;
}
.wc-container .wc-row {
  /*border: 1px dotted #0313fc;*/
  padding: 2px;
}
.wc-container .wc-row.header {
  flex: 0 1 auto;
}
.wc-container .wc-row.content {
  flex: 1 1 auto;
  overflow-y: auto;
}
.wc-container .wc-row.footer {
  flex: 0 1 0px;
}

.material-symbols-rounded.md-10 {
  font-size: 18px !important;
}
