* {box-sizing: border-box}

/* Style the tab */
.tab {
  border: 1px solid #ccc;
  background-color: #f1f1f1;
  height: 450px;
}

/* Style the buttons inside the tab */
.tab div {
  display: block;
  background-color: inherit;
  color: black;
  padding: 10px;
  width: 100%;
  border: none;
  outline: none;
  text-align: left;
  cursor: pointer;
  transition: 0.3s;
  font-size: 17px;
}

/* Change background color of buttons on hover */
.tab div:hover {
  background-color: #ddd;
}

/* Create an active/current "tab button" class */
.tab div.active {
  background-color: #ccc;
}

/* Style the tab content */
.tabcontent {
  border: 1px solid #ccc;
  height: 450px;
  overflow-y: scroll;
  background-color: #CCCCCC;
}
