input[type=search]::-webkit-search-cancel-button {
    -webkit-appearance: searchfield-cancel-button;
}

.speech-wrapper {
  padding-top: 0px;
  padding: 5px 30px;
  background-color: #CCCCCC;
}

.bubble-row {
   display: flex;
   width: 100%;
   justify-content: flex-start;
}

.bubble-row.alt {
     justify-content: flex-end;
}

.bubble {
    /*width: 350px; */
    height: auto;
    display: block;
    background: #f5f5f5;
    border-radius: 4px;
    box-shadow: 2px 8px 5px #555;
    position: relative;
    margin: 0 0 15px;
}

.bubble.alt {
      margin: 0 0 15px;
}

.bubble-text {
      padding: 5px 5px 0px 8px;
}

.bubble-name {
    width: 280px;
    font-weight: 600;
    font-size: 12px;
    margin: 0 0 0px;
    color: #3498db;
    display: flex;
    align-items: center;
    .material-symbols-rounded {
      margin-left: auto;
      font-weight: normal;
      color: #808080;
    }
}
.bubble-name.alt {
      color: #2ecc71;
}

.bubble-timestamp {
  margin-right: auto;
  font-size: 11px;
  text-transform: uppercase;
  color: #bbb
}

.bubble-message {
    font-size: 16px;
    margin: 0px;
    padding: 0px 0px 0px 0px;
    color: #2b2b2b;
    text-align: left;
}

.bubble-arrow {
  position: absolute;
  width: 0;
  bottom:30px;
  left: -16px;
  height: 0px;
}

.bubble-arrow.alt {
    right: -2px;
    bottom: 30px;
    left: auto;
}

.bubble-arrow:after {
  content: "";
  position: absolute;
  border: 0 solid transparent;
  border-top: 9px solid #f5f5f5;
  border-radius: 0 20px 0;
  width: 15px;
  height: 30px;
  transform: rotate(145deg);
}
.bubble-arrow.alt:after {
  transform: rotate(45deg) scaleY(-1);
}

.popover {
  max-width: 400px;
}
.popover-header {
  font-size: 8pt;
  max-width: 400px;
  padding: 5px;
  background-color: #ee;
}

.popover-body {
  white-space: pre-line;
  max-width: 400px;
  padding: 5px;
}
